core

package
v1.5.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 16, 2026 License: GPL-3.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateTempFile

func CreateTempFile(dir, pattern string) (*os.File, error)

CreateTempFile wraps os.CreateTemp with path normalization for Windows

func GetLongPathName

func GetLongPathName(shortPath string) (string, error)

GetLongPathName is a no-op on non-Windows platforms.

func TempDir

func TempDir() string

TempDir returns the appropriate temp directory. On Windows, allows override to avoid 8.3 short filename issues with non-ASCII usernames.

Types

This section is empty.

Directories

Path Synopsis
Package git provides Git repository operations for AE-ADK.
Package git provides Git repository operations for AE-ADK.
Package project provides project initialization, detection, and validation for the AE-ADK Go Edition.
Package project provides project initialization, detection, and validation for the AE-ADK Go Edition.
@MX:ANCHOR: [AUTO] Core package of the TRUST 5 quality gate framework.
@MX:ANCHOR: [AUTO] Core package of the TRUST 5 quality gate framework.

Jump to