Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateTempFile ¶
CreateTempFile wraps os.CreateTemp with path normalization for Windows
func GetLongPathName ¶
GetLongPathName is a no-op on non-Windows platforms.
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package git provides Git repository operations for AE-ADK.
|
Package git provides Git repository operations for AE-ADK. |
|
Package project provides project initialization, detection, and validation for the AE-ADK Go Edition.
|
Package project provides project initialization, detection, and validation for the AE-ADK Go Edition. |
|
@MX:ANCHOR: [AUTO] Core package of the TRUST 5 quality gate framework.
|
@MX:ANCHOR: [AUTO] Core package of the TRUST 5 quality gate framework. |
Click to show internal directories.
Click to hide internal directories.